@@ -221,9 +221,9 @@ class SQLAlchemyIndexer(indexer.IndexerDriver):
         return m
 
     def list_metrics(self, user_id=None, project_id=None, details=False,
-                     **kwargs):
+                     status='active', **kwargs):
         session = self.engine_facade.get_session()
-        q = session.query(Metric).filter(Metric.status == 'active')
+        q = session.query(Metric).filter(Metric.status == status)
         if user_id is not None:
             q = q.filter(Metric.created_by_user_id == user_id)
         if project_id is not None:
